@@ -49,10 +49,10 @@
 
 #include "constants.h"
 #include "types.h"
+#include "entry.h"
 
 #include "cpy.h"
 
-#include "entry.h"
 #include "icons.h"
 #include "misc.h"
 #include "monitor.h"
@@ -67,16 +67,16 @@
 #define CHILD_FILE_LENGTH 64
 
 
-G_MODULE_EXPORT
+static
 gboolean waste = TRUE;
 G_MODULE_EXPORT
 gboolean force_override = FALSE;
 /* this *must* be thread safe, (hence _POSIX_PATH_MAX) */
 G_MODULE_EXPORT
 char child_file [_POSIX_PATH_MAX];
-G_MODULE_EXPORT
-char dlg_result;
-G_MODULE_EXPORT
+
+static int overwrite_dlg_result;
+static
 time_t initial;
 
 static gint stop_watch;
@@ -99,13 +99,13 @@ static void set_innerloop(gboolean state);
 static void close_it(void)
 {
     gtk_main_quit();
-    gtk_widget_destroy(tree_details->remove);
-    tree_details->remove = NULL;
+    gtk_widget_destroy(tree_details->overwrite);
+    tree_details->overwrite = NULL;
 }
 
 static gboolean on_destroy_event(GtkWidget * widget, GdkEvent * event, gpointer user_data)
 {
-    dlg_result = DLG_CANCEL;
+    overwrite_dlg_result = DLG_CANCEL;
     close_it();
     return TRUE;
 }
@@ -113,18 +113,18 @@ static gboolean on_destroy_event(GtkWidget * widget, GdkEvent * event, gpointer
 static void on_copy_no_activate(GtkButton * button, gpointer user_data)
 {
     GtkWidget *check;
-    dlg_result = DLG_NO;
-    check = lookup_widget(tree_details->remove,"togglebutton1");
+    overwrite_dlg_result = DLG_NO;
+    check = lookup_widget(tree_details->overwrite,"togglebutton1");
     force_override = gtk_toggle_button_get_active((GtkToggleButton *) check);
-    if (force_override) dlg_result = DLG_CANCEL;
+    if (force_override) overwrite_dlg_result = DLG_CANCEL;
     close_it();
 }
 
 static void on_copy_yes_activate(GtkButton * button, gpointer user_data)
 {
     GtkWidget *check;
-    dlg_result = DLG_YES;
-    check = lookup_widget(tree_details->remove,"togglebutton1");
+    overwrite_dlg_result = DLG_YES;
+    check = lookup_widget(tree_details->overwrite,"togglebutton1");
     force_override = gtk_toggle_button_get_active((GtkToggleButton *) check);
 	waste = FALSE;
 
@@ -133,8 +133,8 @@ static void on_copy_yes_activate(GtkButton * button, gpointer user_data)
 static void on_copywaste_yes_activate(GtkButton * button, gpointer user_data)
 {
     GtkWidget *check;
-    dlg_result = DLG_YES;
-    check = lookup_widget(tree_details->remove,"togglebutton1");
+    overwrite_dlg_result = DLG_YES;
+    check = lookup_widget(tree_details->overwrite,"togglebutton1");
     force_override = gtk_toggle_button_get_active((GtkToggleButton *) check);
 	waste = TRUE;
 
@@ -146,19 +146,19 @@ static int make_overwrite_dialog(char *err, char *target, char *src)
 {
     gchar *mess;
     struct stat st;
-    if(tree_details->remove)
+    if(tree_details->overwrite)
 	assert_not_reached();
 
     waste = TRUE;
-    tree_details->remove = create_remove();
-    gtk_window_set_position(GTK_WINDOW(tree_details->remove), GTK_WIN_POS_MOUSE);
+    tree_details->overwrite = create_remove();
+    gtk_window_set_position(GTK_WINDOW(tree_details->overwrite), GTK_WIN_POS_MOUSE);
 
-    g_signal_connect_object(lookup_widget(tree_details->remove,"cancelbutton"), "clicked", G_CALLBACK(on_copy_no_activate), NULL, 0);
-    g_signal_connect_object(lookup_widget(tree_details->remove,"removebutton"), "clicked", G_CALLBACK(on_copy_yes_activate), NULL, 0);
-    g_signal_connect_object(lookup_widget(tree_details->remove,"wastebutton"), "clicked", G_CALLBACK(on_copywaste_yes_activate), NULL, 0);
+    g_signal_connect_object(lookup_widget(tree_details->overwrite,"cancelbutton"), "clicked", G_CALLBACK(on_copy_no_activate), NULL, 0);
+    g_signal_connect_object(lookup_widget(tree_details->overwrite,"removebutton"), "clicked", G_CALLBACK(on_copy_yes_activate), NULL, 0);
+    g_signal_connect_object(lookup_widget(tree_details->overwrite,"wastebutton"), "clicked", G_CALLBACK(on_copywaste_yes_activate), NULL, 0);
 
-    g_signal_connect_object(tree_details->remove, "delete-event", G_CALLBACK(on_destroy_event), NULL, 0);
-    g_signal_connect_object(tree_details->remove, "destroy-event", G_CALLBACK(on_destroy_event), NULL, 0);
+    g_signal_connect_object(tree_details->overwrite, "delete-event", G_CALLBACK(on_destroy_event), NULL, 0);
+    g_signal_connect_object(tree_details->overwrite, "destroy-event", G_CALLBACK(on_destroy_event), NULL, 0);
 
     /* dialog specifics */
    
@@ -166,35 +166,49 @@ static int make_overwrite_dialog(char *err, char *target, char *src)
     {
 	char mess[_POSIX_PATH_MAX];
 	sprintf(mess, _("Try again (%s)?"), err);
-	gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->remove,"label16"), mess);
-	hideit(tree_details->remove, "question");
+	gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->overwrite,"label16"), mess);
+	hideit(tree_details->overwrite, "question");
     }
     else
     {
-	gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->remove,"label16"), _("Warning"));
-	hideit(tree_details->remove, "warning");
+	gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->overwrite,"label16"), _("Warning"));
+	hideit(tree_details->overwrite, "warning");
     }
 
-    /*gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->remove,"label22"), _("Overwrite"));    */
+    gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->overwrite,"label22"), _("Overwrite"));    
 
     lstat(target,&st);
     if (src){
        struct stat s_st;
-       lstat(src,&s_st);
+       gchar *t1=NULL,*t2=NULL;
+       gchar *s1=NULL,*s2=NULL;
+       if (lstat(src,&s_st)<0){
+	   g_warning("cannot stat %s",src);
+       }
+       {
+	   s1=g_strdup(time_to_string(s_st.st_mtime));
+	   s2=g_strdup(sizetag((off_t)s_st.st_size,-1));
+	   t1=g_strdup(my_utf_string(target));
+	   t2=g_strdup(my_utf_string(src));
+       }
        mess=g_strdup_printf(_("Overwrite %s\n(%s %s)\n with \n%s\n(%s %s)?"),
-	       abreviate(target),time_to_string(st.st_mtime),sizetag((off_t)st.st_size, -1),
-	       abreviate(src),time_to_string(s_st.st_mtime),sizetag((off_t)s_st.st_size,-1));
+	      t1,time_to_string(st.st_mtime),sizetag((off_t)st.st_size, -1),
+	      t2,s1,s2);
+       g_free(s1);
+       g_free(s2);
+       g_free(t1);
+       g_free(t2);
 
     } else {
        mess=g_strdup_printf("%s\n(%s %s)",
-	       abreviate(target),time_to_string(st.st_mtime), sizetag((off_t)st.st_size, -1)); 
+	       (target),time_to_string(st.st_mtime), sizetag((off_t)st.st_size, -1)); 
     }
 
-    gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->remove,"label20"), mess);
+    gtk_label_set_text((GtkLabel *) lookup_widget(tree_details->overwrite,"label20"), mess);
     g_free(mess);mess=NULL;
     {
       GdkPixbuf	*pb;
-      GtkImage *image=(GtkImage *)lookup_widget(tree_details->remove,"adicon");
+      GtkImage *image=(GtkImage *)lookup_widget(tree_details->overwrite,"adicon");
       pb = icon_tell(MEDIUM, "xfce/waste_basket_full");
       if (pb) {
 	gtk_image_set_from_pixbuf (image, pb);
@@ -202,24 +216,24 @@ static int make_overwrite_dialog(char *err, char *target, char *src)
       }
     }
 
-    gtk_widget_realize(tree_details->remove);
-    gtk_widget_show(tree_details->remove);
+    gtk_widget_realize(tree_details->overwrite);
+    gtk_widget_show(tree_details->overwrite);
     if (getenv("XFFM_DEFAULT_UNLINK") && strcmp(getenv("XFFM_DEFAULT_UNLINK"),"unlink")==0){
-	  gtk_widget_grab_focus (lookup_widget(tree_details->remove,"removebutton"));	    
+	  gtk_widget_grab_focus (lookup_widget(tree_details->overwrite,"removebutton"));	    
     }
     else if (getenv("XFFM_DEFAULT_UNLINK") && strcmp(getenv("XFFM_DEFAULT_UNLINK"),"waste")==0){
-	  gtk_widget_grab_focus (lookup_widget(tree_details->remove,"wastebutton"));	    
+	  gtk_widget_grab_focus (lookup_widget(tree_details->overwrite,"wastebutton"));	    
     }
 
-    gtk_window_set_transient_for(GTK_WINDOW(tree_details->remove), 
+    gtk_window_set_transient_for(GTK_WINDOW(tree_details->overwrite), 
 		    GTK_WINDOW(tree_details->window));
     
     if (strstr(target,"/..Wastebasket"))    {
-	hideit(tree_details->remove, "wastebutton");
+	hideit(tree_details->overwrite, "wastebutton");
     }
 
     gtk_main();
-    return dlg_result;
+    return overwrite_dlg_result;
 }
 
 
@@ -264,16 +278,16 @@ static int ok_input(char *target, tree_entry_t * s_en)
 	return (DLG_CONTINUE);
     }
     try_again:
-    dlg_result = DLG_YES;
+    overwrite_dlg_result = DLG_YES;
     warn_target_exists(target, s_en->path);
-    if(dlg_result == DLG_YES && waste){
+    if(overwrite_dlg_result == DLG_YES && waste){
 	if(!wasteit(target))
 	{
 	    /* error message set within wasteit() */
 	    goto try_again;
 	}
     }
-    return dlg_result;
+    return overwrite_dlg_result;
 }
 
 #if 0
@@ -282,14 +296,14 @@ static int error_continue(char *err, char *file)
     if(force_override)
     {
 	print_diagnostics("xfce/error", err, " : ", file, "\n", NULL);
-	dlg_result = DLG_CANCEL;
+	overwrite_dlg_result = DLG_CANCEL;
     }
     else
     {
-	dlg_result = DLG_CANCEL;
+	overwrite_dlg_result = DLG_CANCEL;
 	make_overwrite_dialog(err, file, NULL);
     }
-    return dlg_result;
+    return overwrite_dlg_result;
 }
 #endif
 
@@ -581,6 +595,7 @@ gchar *SimpleTmpList (char *tgt, char *src)
     countT = nitems = 1;
     return fname;
 }
+
 G_MODULE_EXPORT
 int warn_target_exists (char *target, char *src)
 {
@@ -592,11 +607,11 @@ int warn_target_exists (char *target, char *src)
     }
     else
     {
-	dlg_result = DLG_CANCEL;
+	overwrite_dlg_result = DLG_CANCEL;
 	make_overwrite_dialog(NULL, target, src);
     }
-    if (waste && dlg_result==DLG_YES) return DLG_WASTE;
-    return dlg_result;
+    if (waste && overwrite_dlg_result==DLG_YES) return DLG_WASTE;
+    return overwrite_dlg_result;
 }
 
 G_MODULE_EXPORT
@@ -676,6 +691,7 @@ char *CreateTmpList (GList * list, tree_entry_t * t_en)
 G_MODULE_EXPORT
 gboolean IndirectTransfer (int mode, char *tmpfile)
 {
+    force_override = FALSE;
 
     if(CHILD_FILE_LENGTH < strlen(tmpfile) + 1) {
 	printf("IndirectTransfer(): CHILD_FILE_LENGTH < strlen(tmpfile)\n");
