@@ -630,6 +630,48 @@ const gchar *get_xffm_home (void){
     return home;
 }
 
+static 
+void purge_cache_files(const gchar *cd){
+    DIR *directory;
+    char *fullpath;
+    struct dirent *d;
+	gchar *xdg_dir;
+	gchar *cache_dir;
+	time_t now=time(NULL);
+	xdg_dir=xfce_resource_save_location (XFCE_RESOURCE_CACHE,"/",TRUE);
+	cache_dir = g_build_filename(xdg_dir,"xfce4","xffm",cd,NULL);  
+	g_free(xdg_dir);
+	if (!cache_dir) return;
+	directory = opendir(cache_dir);
+	if(!directory){
+	    DBG("cannot open %s",cache_dir);
+	    g_free(cache_dir);
+	    return;
+	}
+	while((d = readdir(directory)) != NULL) 
+	{
+	    struct stat st;
+	    if (strcmp(d->d_name,".")==0 || strcmp(d->d_name,"..")==0)continue;
+	    fullpath = g_build_filename((gchar *)cache_dir, d->d_name,NULL);
+	    if (strcmp(d->d_name,"..Wastebasket")==0){
+		if (fork()==0){
+		    execlp("rm","rm","-rf",fullpath,NULL);
+		    _exit(123);
+		}
+	    }
+	    if (stat(fullpath,&st) == 0){
+		if (now - st.st_mtime > 3600*24*30) {
+		    TRACE("removing %s",fullpath);
+		    unlink(fullpath);
+		}
+		/*else TRACE("not removing %s: age is %d (%d days)",fullpath,(now - st.st_mtime),(now - st.st_mtime)/3600/24 );*/
+	    }
+	    g_free(fullpath);
+        }
+	closedir(directory);
+        g_free(cache_dir);
+	    
+}
 /* this could also delete tmp files in use by another xffm instance 
  * (very slight possibility)*/
 G_MODULE_EXPORT
@@ -652,6 +694,9 @@ void cleanup_tmpfiles (void)
 	}
     }
     closedir(directory);
+    purge_cache_files("smb");
+    purge_cache_files("cache");
+    purge_cache_files("thumbnails");
     return;
 }
 
@@ -711,7 +756,7 @@ count_hidden_files(gchar *path)
 }
 
 G_MODULE_EXPORT
-void set_entry_tag (GtkTreeView * treeview, tree_entry_t * en, off_t tama) 
+void set_entry_tag (tree_entry_t * en, off_t tama) 
 {
     int hcount;
 
